===============================
Django Auto Healthchecks
===============================


.. image:: https://img.shields.io/pypi/v/django_auto_healthchecks.svg
        :target: https://pypi.python.org/pypi/django_auto_healthchecks

.. image:: https://img.shields.io/travis/cronitorio/django_auto_healthchecks.svg
        :target: https://travis-ci.org/cronitorio/django_auto_healthchecks

.. image:: https://readthedocs.org/projects/django-auto-healthchecks/badge/?version=latest
        :target: https://django-auto-healthchecks.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/cronitorio/django_auto_healthchecks/shield.svg
     :target: https://pyup.io/repos/github/cronitorio/django_auto_healthchecks/
     :alt: Updates


Create powerful healthchecks directly from your django urls.py with Cronitor.io
* Free software: MIT license
* Documentation: https://django-auto-healthchecks.readthedocs.io.


Credits
---------

This package was cut with Cookiecutter: https://github.com/audreyr/cookiecutter

